@@ -212,6 +212,19 @@ libvirt_funcs = [ 'virStorageVolWipe',
                   'virConnectGetCPUModelNames',
                   'virDomainMigrate3',
                   'virDomainGetCPUStats',
+                  'virNetworkGetDHCPLeases',
+                  'virNodeAllocPages',
+                  'virDomainGetTime',
+                  'virDomainSetTime',
+                  'virConnectGetDomainCapabilities',
+                  'virDomainCoreDumpWithFormat',
+                  'virDomainFSFreeze',
+                  'virDomainFSThaw',
+                  'virDomainGetFSInfo',
+                  'virNodeGetFreePages',
+                  'virDomainDefineXMLFlags',
+                  'virDomainRename',
+                  'virDomainSetUserPassword',
                 ]
 
 libvirt_qemu_funcs = [ 'virDomainQemuMonitorCommand',
@@ -404,6 +417,30 @@ libvirt_consts = [ 'VIR_MIGRATE_LIVE',
                    'VIR_DOMAIN_SNAPSHOT_CREATE_REUSE_EXT',
                    'VIR_DOMAIN_SNAPSHOT_CREATE_QUIESCE',
                    'VIR_DOMAIN_SNAPSHOT_CREATE_ATOMIC',
+                   'VIR_CONNECT_LIST_STORAGE_POOLS_GLUSTER',
+                   'VIR_CONNECT_LIST_STORAGE_POOLS_ZFS',
+                   'VIR_STORAGE_VOL_NETDIR',
+                   'VIR_IP_ADDR_TYPE_IPV4',
+                   'VIR_IP_ADDR_TYPE_IPV6',
+                   'VIR_CONNECT_COMPARE_CPU_FAIL_INCOMPATIBLE',
+                   'VIR_DOMAIN_UNDEFINE_NVRAM',
+                   'VIR_DOMAIN_BLOCK_JOB_TYPE_ACTIVE_COMMIT',
+                   'VIR_DOMAIN_BLOCK_JOB_INFO_BANDWIDTH_BYTES',
+                   'VIR_DOMAIN_BLOCK_JOB_SPEED_BANDWIDTH_BYTES',
+                   'VIR_DOMAIN_BLOCK_COMMIT_ACTIVE',
+                   'VIR_DOMAIN_BLOCK_COMMIT_RELATIVE',
+                   'VIR_DOMAIN_BLOCK_COMMIT_BANDWIDTH_BYTES',
+                   'VIR_DOMAIN_BLOCK_IOTUNE_SIZE_IOPS_SEC',
+                   'VIR_STORAGE_POOL_CREATE_NORMAL',
+                   'VIR_STORAGE_POOL_CREATE_WITH_BUILD',
+                   'VIR_STORAGE_POOL_CREATE_WITH_BUILD_OVERWRITE',
+                   'VIR_STORAGE_POOL_CREATE_WITH_BUILD_NO_OVERWRITE',
+                   'VIR_STORAGE_VOL_CREATE_REFLINK',
+                   'VIR_STORAGE_VOL_DELETE_WITH_SNAPSHOTS',
+                   'VIR_DOMAIN_QEMU_AGENT_COMMAND_SHUTDOWN',
+                   'VIR_DOMAIN_DEFINE_VALIDATE',
+                   'VIR_DOMAIN_PASSWORD_ENCRYPTED',
+                   'VIR_DOMAIN_TIME_SYNC',
                  ]
 
 virterror_consts = [
@@ -432,6 +469,14 @@ virterror_consts = [
                     'VIR_FROM_STATS_LINUX',
                     'VIR_FROM_XEN_INOTIFY',
                     'VIR_FROM_SECURITY',
+                    'VIR_DOMAIN_CORE_DUMP_FORMAT_RAW',
+                    'VIR_DOMAIN_CORE_DUMP_FORMAT_KDUMP_ZLIB',
+                    'VIR_DOMAIN_CORE_DUMP_FORMAT_KDUMP_LZO',
+                    'VIR_DOMAIN_CORE_DUMP_FORMAT_KDUMP_SNAPPY',
+                    'VIR_MIGRATE_AUTO_CONVERGE',
+                    'VIR_MIGRATE_RDMA_PIN_ALL',
+                    'VIR_DOMAIN_SHUTDOWN_PARAVIRT',
+                    'VIR_DOMAIN_REBOOT_PARAVIRT',
                    ]
 
 libvirt_qemu_consts = [
